# Les lois de Newton

Avant d'entrer à proprement parler dans ce chapitre, nous devons voir quelques notions mathématiques (ou les rappeler). 

## Vecteurs

Jusqu'ici dans le cours, nous avons vu des grandeurs appelées *scalaires*, c'est-à-dire des nombres, tels que la température, $T$, le temps, $t$, la masse, $m$, ... Nous pouvons représenter ces nombres sur une droite infinie: les nombres réels. Nous pouvons les comparer (dire lequel est plus grand que l'autre), les additionner, les soustraire, les multiplier, les diviser, ...

Pour ce chapitre, nous allons devoir étendre ce concept de *scalaires* pour pouvoir décrire des concepts plus complexes. 

### Motivation

Prenons l'exemple de la carte de la @fig:depl_vec. Si nous nous déplaçons à vol d'oiseau et ne connaissons que la distance parcourue, disons $60\ \km$, et un point de départ, ici G'nèèèève (de Dieu). Nous avons une infinités de destinations possibles (tous les point du cercle noir). Si en revanche nous ajoutons à la distance parcourue une direction (la direction de la flèche noire), nous avons une destination unique. Nous définissons le déplacement comme étant la combinaison de ces deux informations: une direction et une longueur (de façon plus formelle la longueur est appelée *module*). Si ne nous déplacions pas en ligne droite, nous ne pourrions pas décrire notre trajet en fonction du déplacement uniquement. En effet, le déplacement d'un objet tel que nous le définissons ici ne prend pas du tout en compte le chemin effectivement parcouru (le trait rouge sur la @fig:depl_vec), mais uniquement le point de départ et d'arrivée.

![L'ensemble des destinations possibles si nous n'avions que le dép comme information (cercle noir), la position finale avec la distance et la direction de déplacement.](figs/deplacement_vecteur.svg){#fig:depl_vec width=70%}

### L'arithmétique des vecteurs

Le déplacement est un *vecteur*, noté $\vec s$. Il est représenté par une flèche (voir @fig:depl_vec) dont la longueur, norme ou module, est noté $||\vec s||$. Le même déplacement $\vec s$ peut être décomposé en deux autres déplacements (voir la @fig:vec): d'abord en un déplacement $\vec s_d$ vers la droite, puis en un déplacement vers le haut $\vec s_h$. Il faut noter que cette décomposition peut s'effectuer dans un ordre différent: d'abord vers le haut puis vers la droite. Cette suite de déplacements définit l'addition de deux vecteurs
$$\vec s=\vec s_d+\vec s_h=\vec s_h+\vec s_d.$$

![La décomposition du vecteur $\vec s$ en bleu en deux déplacements $\vec s_d$ et $\vec s_h$. De façon plus générale toute somme de vecteur $\vec s_3=\vec s_1+\vec s_2.$](figs/vecteur.svg){#fig:vec width=30%}

Géométriquement, la somme de deux vecteurs se représente toujours ainsi pour deux vecteurs quelconques 
$$\vec s_3=\vec s_1+\vec s_2.$$ 
La somme se représente en mettant bout à bout le vecteur $\vec s_1$ puis le vecteur $\vec s_2$. Cette représentation nous montre que la relation entre les normes est la suivante
$$||\vec s_3||=||\vec s_1+\vec s_2||\leq||\vec s_1||+||\vec s_2||.$$ 
En d'autres termes la somme des longueurs de $\vec s_1$ et $\vec s_2$ 
et plus petite ou égale la longueur de la somme de $\vec s_1$ et $\vec s_2$[^4].
On peut ainsi décomposer un déplacement en un nombre arbitraire de déplacements intermédiaires (voir la @fig:somme_vec). Il faut noter que l'ordre dans lequel la somme est effectuée n'a pas d'importance. On dit que la somme est *commutative* (comme pour les scalaires d'ailleurs). On constate d'ailleurs sur cette même figue que la longueur 
Une propriété de la somme de deux vecteurs qui est très importante c'est qu'elle est définie de telle façon à ce que le résultat soit toujours un vecteur.

![La somme de quatre vecteurs. En partant du point $P_i$ on arrive toujours au point $P_f$ peu importe l'ordre dans lequel nous effectuons la somme.](figs/somme_vecteurs.svg){#fig:somme_vec width=30%}

Un cas particulier d'addition de vecteur est l'addition de vecteurs parallèles et antiparallèles. Dans le cas parallèle les vecteurs, $\vec s_1$ et $\vec s_2$ ont la même direction. Le vecteur $\vec s_3=\vec s_1+\vec s_2$ aura donc la même direction que $\vec s_1$ et $\vec s_2$ et sa norme sera la somme des normes de $\vec s_1$ et $\vec s_2$ (voir la @fig:somme_vec_para). 

![La somme de deux vecteurs parallèles. ](figs/somme_vecteurs_para.svg){#fig:somme_vec_para width=30%}

Dans le cas anti-parallèle les vecteurs $\vec s_1$ et $\vec s_2$ les vecteurs pointent dans des directions opposées. Le vecteur $\vec s_3=\vec s_1+\vec s_2$ aura donc soit la direction de $\vec s_1$ soit celle de $\vec s_2$ et sa norme sera la différence des normes de $\vec s_1$ et $\vec s_2$ (voir la @fig:somme_vec_anti_para).

![La somme de deux vecteurs anti-parallèles. ](figs/somme_vecteurs_antipara.svg){#fig:somme_vec_anti_para width=30%}

De façon très similaire à ce que nous faisons pour les scalaires (les nombres entiers, les rationnels et les réels) nous pouvons définir l'opposé d'un vecteur $\vec s$ et le noter $-\vec s$. Comme pour les scalaires, nous aimerions que le vecteur $-\vec s$ soit ``l'inverse'' du vecteur $\vec s$ pour l'addition. On aimerait donc que la la somme $\vec s+(-\vec s)=\vec{0}$. En d'autres termes, le départ départ de $\vec s$ soir le même que le point d'arrivée après la somme (voir la @fig:somme_vec_anti_para_zero). 

![La somme de deux vecteurs anti-parallèles de même longueur. ](figs/somme_vecteurs_antipara_zero.svg){#fig:somme_vec_anti_para_zero width=30%}

Une autre façon d'écrire cette somme est de faire comme pour les scalaires:
$$\vec s+(-\vec s)=\vec s-\vec s=\vec{0}.$$
Cette façon de faire nous permet de définir la soustraction de deux vecteurs,
$\vec s_1$ et $\vec s_2$ 
$$\vec s_1-\vec s_2=\vec s_1+(-\vec s_2).$$
Comme on peut le voir sur la @fig:soustraction_vecteurs la soustraction de deux vecteurs consiste, en fait, à d'abord prendre prendre l'inverse du vecteur soustrait, $-\vec s_2$ et de l'ajouter au premier vecteur.

![La soustraction de deux vecteurs. ](figs/soustraction_vecteurs.svg){#fig:soustraction_vecteurs width=30%}

Comme l'addition de deux vecteur est commutative, la soustraction peut également s'écrire dans un ordre différent (attention elle n'est pas commutative)
$$\vec s_3=\vec s_1-\vec s_2=\vec s_1+(-\vec s_2)=-\vec s_2+\vec s_1.$$

Un autre opération primordiale pour les vecteur est le produit avec un scalaire. Si nous avons un nombre $\alpha$, et un vecteur $\vec s_1$, nous pouvons définir le produit 
$$\vec s_2=\alpha\cdot\vec s_1.$$
Si $\alpha>0$, l'effet de cette multiplication est de modifier la norme de $\vec s_1$ proportionnellement à $\alpha$, mais d'en laisser la direction inchangée (voir la @fig:vecteur_produit la ligne du haut): le vecteur $\vec s_2$ est parallèle avec le vecteur $\vec s_1$. Lorsque $\alpha<0$ on change toujours la norme proportionnellement à $\alpha$, mais on change également la direction du vecteur (voir la @fig:vecteur_produit la ligne du bas): le vecteur $\vec s_2$ est anti-parallèle avec le vecteur $\vec s_1$. Il y a deux cas particuliers:

1. Lorsque $\alpha=1$, le vecteur $\vec s_2=1\cdot\vec s_1=\vec s_1$, et donc le vecteur $\vec s_1$ est inchangé.
2. Lorsque $\alpha=-1$, le vecteur $\vec s_2=-1\cdot\vec s_1=-\vec s_1$, t donc le vecteur $\vec s_2$ est le vecteur *opposé* à $\vec s_1$.

![Produit d'un vecteur avec un scalaire $\alpha$ pour les 4 cas possibles.](figs/produit_vecteur.svg){#fig:vecteur_produit width=50%}

Une propriété du produit d'un vecteur avec un scalaire est qu'elle est définie de telle façon à ce que le résultat soit toujours un vecteur. On peut à présent comme pour le produit entre scalaire voir les propriétés de *distributivité*. Soient $\alpha_1$, $\alpha_2$ deux scalaires, et $\vec s_1$, $\vec s_2$ deux vecteurs 
$$\begin{aligned}
\alpha_1\cdot(\vec s_1+\vec s_2)=\alpha_1\cdot\vec s_1+\alpha_1\cdot\vec s_2,\\
(\alpha_1+\alpha_2)\cdot\vec s_1=\alpha_1\cdot\vec s_1+\alpha_2\cdot\vec s_1.\end{aligned}$$
Pour la deuxième propriété on peut voir un exemple sur la @fig:vecteur_produit_distr. 

![La distributivité de la somme de deux scalaire multipliés avec un vecteur $\vec s_1$ pour $\alpha_1=2$ et $\alpha_2=3$.](figs/produit_vecteur_distr.svg){#fig:vecteur_produit_distr width=70%}

Le produit avec un scalaire ainsi définit nous permet de définir le *vecteur unitaire*. Le vecteur unitaire d'un vecteur $\vec s$ se définit par
$$\vec{n}=\frac{\vec s}{||\vec s||}.$$
Ce vecteur comme son nom l'indique a une longueur (norme) de un
$$||\vec{n}||=\left|\left|\frac{\vec s}{||\vec s||}\right|\right|=\frac{||\vec s||}{||\vec s||}=1,$$
et la même direction que $\vec s$. Le vecteur $\vec s$ peut donc s'écrire à l'aide du vecteur unitaire $\vec{n}$ comme
$$\vec s=||\vec s||\cdot \vec{n}.$$

### Systèmes de coordonnées

Depuis le début de ce chapitre nous avons vu des règles très générales pour représenter les vecteurs et en faire des sommes et des multiplications avec des scalaires. Il nous reste à trouver un moyen de les représenter numériquement. 

Le moyen le plus commun de se représenter un vecteur dans le plan est de passer par les coordonnées *cartésiennes* (voir la @fig:cartesiennes).

![Le vecteur $\vec s$ est décomposé en deux parties $\vec s_x$, et $\vec s_y$.](figs/composantes.svg){#fig:cartesiennes width=70%}

Le vecteur est $\vec s$ est donné par
$$\vec s=\vec s_x+\vec s_y.$$ 
En définissant deux vecteurs unitaires particuliers qui sont alignés avec
l'axe horizontal et vertical respectivement (voir @fig:vec_e)
$$\vec e_x=\vectwo{1}{0},\quad \vec e_y=\vectwo{0}{1}.$${#eq:vec_e}

![Les vecteurs unitaires $\vec e_x$ et $\vec e_y$.](figs/vec_e.svg){#fig:vec_e width=40%}

En utilisant les vecteurs unitaires, $\vec e_x$ et $\vec e_y$, les vecteurs $\vec s_x$ et $\vec s_y$ peuvent s'écrire $\vec s_x=\vec e_x\cdot s_x$ et $\vec s_y=\vec e_y\cdot s_y$, où $\vec e_x$ et $\vec e_y$ sont les vecteurs unitaires dans la direction horizontale et verticale respectivement (voir @eq:vec_e).

La norme des composantes de $\vec s_x$ et $\vec s_y$ peut se calculer à l'aide de la trigonométrie. On a donc
$$\begin{aligned}
s_x&=||\vec s_x||=||\vec s||\cos(\theta),\\
s_y&=||\vec s_y||=||\vec s||\sin(\theta),
\end{aligned}$${#eq:coord_pol}
où $\theta$ est l'angle entre l'axe horizontal et le vecteur $\vec s$
et où on note les *coordonnées* cartésiennes de $\vec s$, $s_x$ et $s_y$.
Le vecteur $\vec s$ peut donc se représenter uniquement avec ces deux nombres $s_x$ et $s_y$ sous entendu que la première coordonnée est le long de l'axe horizontal et la seconde selon l'axe vertical.

Maintenant que nous avons défini les composantes $s_x$ et $s_y$, nous pouvons additionner les vecteurs en coordonnées cartésiennes. Soient deux vecteurs $\vec{u}$ et $\vec{v}$, et dont la somme est $\vec{w}=\vec{u}+\vec{v}$, les coordonnées de $\vec{w}$ sont données par
$$\begin{aligned}
w_x&=u_x+v_x,\\
w_y&=u_y+v_y.
\end{aligned}$$
Nous pouvons assez facilement nous en convaincre à l'aide de la @fig:composantes_add.
De façon similaire, nous pouvons calculer le produit entre un scalaire et un vecteur. 
Nous avons que $\vec{u}=\alpha\cdot \vec{v}$ est donné par
$$\begin{aligned}
u_x&=\alpha\cdot v_x,\\
u_y&=\alpha\cdot v_y.
\end{aligned}$$

![La somme de deux vecteurs $\vec{u}$ et $\vec{v}$ en composantes.](figs/somme_composantes.svg){#fig:composantes_add width=70%}

La notation pour la plus compact pour noter les composantes d'un vecteur 
$$\vec s=\vectwo{s_x}{s_y}.$$
Avec la représentation en composantes cartésiennes, il est aisé de calculer la longueur d'un vecteur $s=||\vec s||$ à l'aide du théorème de Pythagore
$$s=\sqrt{s_x^2+s_y^2}.$$

---

Exercice (Opérations sur les vecteurs) #

1. Dessiner le vecteur $\vec{v}=\vectwo{2}{3}$ dans le système de coordonnées cartésien.
2. Additionner les vecteur $\vec{u}=\vectwo{2}{3}$ et $\vec{v}=\vectwo{1}{3}$, d'abord 
à l'aide d'un dessin, puis avec les règles vues précédemment.
3. Calculer la longueur de la somme trouvée précédemment $\vec{w}=\vec{u}+\vec{v}$.
4. Calculer l'angle $\theta$ pour $\vec{w}$.
5. Calculer 
$$\alpha\cdot\vec{u}+\beta\cdot\vec{v},$$
avec $\alpha=2$ et $\beta=-1/2$.

---

De l'@eq:coord_pol, on voit qu'on pourrait aussi utiliser un autre système de coordonnées. En utilisant le couple formé par l'angle $\theta$ et la longueur $s$. On appelle cette représentation les coordonnée polaires (voir la @fig:composantes_pol). 

![Le vecteur $\vec s$ peut être représenté selon ses composantes cartésiennes, $s_x$ et $s_y$ ou selon ses coordonnées polaires, $s$ et $\theta$.](figs/composantes_pol.svg){#fig:composantes_pol width=40%}

---

Exercice (Changement de coordonnées) #

Soit un vecteur $\vec s$ dont les coordonnées cartésiennes sont 
$$\vec s=\vectwo{s_x}{s_y}.$$ 
Ecrire la transformation qu'il faut effectuer pour avoir les coordonnées polaires $\vec s=\vectwo{s}{\theta}_\mathrm{polaires}$. Calculer $\theta$ et $s$ pour les vecteurs $\vec s=\vectwo{1}{1}$ et $\vec s=\vectwo{-1}{1}$ en coordonnées cartésiennes.

---

### Le produit scalaire

Jusqu'ici nous avons vu comment additionner les vecteurs et les multiplier par des scalaires. Nous n'avons cependant pas encore vu un moyen pour les multiplier entre eux.
Une façon de définir un tel produit, est le *produit scalaire*. Le produit scalaire entre deux vecteur $\vec{u}$ et $\vec{v}$ se calcule comme
$$\vec{u}\cdot\vec{v}=||\vec{u}||\cdot||\vec{v}||\cdot\cos(\theta).$$
Le produit scalaire s'interprète donc comme le produit entre la norme de $\vec{u}$ 
et la projection de $\vec{v}$ sur $\vec{u}$ et vice versa (voir la @fig:produit_scalaire). 

![Interprétation géométrique du produit scalaire entre $\vec{u}$ et $\vec{v}$.](figs/scalar_prod.svg){#fig:produit_scalaire width=40%}

Les propriétés du cosinus nous disent que 
si les deux vecteurs forment un angle de $90^\circ$ entre eux (ou $\pi/2$ en radians) le produit scalaire est nul
$$\vec{u}\cdot\vec{v}=||\vec u||\cdot ||\vec v||\cdot\cos\left(\pi/2\right)=0.$$
Ces vecteurs sont dit orthogonaux ou normaux (voir @fig:scalaire_orthogonal).
Les vecteurs $\vec e_x$ et $\vec e_y$ sont orthogonaux
$$\vec e_x\cdot\vec e_y=||(1,0)||\cdot||(0,1)||\cdot\cos(\pi/2)=1\cdot 1\cdot 0=0.$$ 

![Interprétation géométrique du produit scalaire entre $\vec{u}$ et $\vec{v}$
pour des vecteurs orthogonaux.](figs/scalaire_orthgonal.svg){#fig:scalaire_orthogonal width=40%}

En revanche si $\vec{u}$ et $\vec{v}$ sont parallèles ou anti-parallèles le produit scalaire est le produit des normes de $\vec{u}$ et $\vec{v}$ (avec un signe négatif si les vecteurs sont anti-parallèles)
$$\vec{u}\cdot\vec{v}=||\vec{u}||\cdot||\vec{v}||\cdot\cos{0}=||\vec u||\cdot||\vec v||\cdot1=||\vec u||\cdot||\vec v||.$$
Un cas particulier est le produit scalaire d'un vecteur $\vec{v}$ avec lui-même
$$\vec{v}\cdot\vec{v}=||\vec v||\cdot ||\vec v||\cdot\cos{0}=||\vec v||^2.$$

De cette définition, il est aisé de voir que le produit scalaire est commutatif
$$\vec{u}\cdot\vec{v}=||\vec{v}||\cdot||\vec{u}||\cdot\cos(\theta)=\vec{v}\cdot\vec{u}.$$

---

Exercice (Propriétés du produit scalaire) #

Montrer que le produit scalaire a les propriétés suivantes. Soient $\vec{u}$, 
$\vec{v}$, et $\vec{w}$ trois vecteurs et soit $\alpha$ un scalaire:
$$\begin{aligned}
\vec{u}\cdot(\vec{v}+\vec{w})=\vec{u}\cdot\vec{v}+\vec{u}\cdot\vec{w},\\
\alpha(\vec{u}\cdot\vec{v})=(\alpha\vec{u})\cdot\vec{v}=\vec{u}\cdot(\alpha\vec{v}).
\end{aligned}$$

---

Il est important de noter que le produit scalaire prend deux vecteurs et les transforme en un scalaire (un nombre).

Il existe une définition alternative pour le produit scalaire qui vous sera
très utile pour son implémentation informatique
$$
\vec u \cdot \vec v =u_x\cdot v_x + u_y\cdot v_y.
$$

---

Travail pratique (Librairie de manipulation de vecteurs) #

Écrire une librairie de manipulation de vecteur en deux dimensions (par groupe de 5).

0. Écrire la structure de données contenant un vecteur à deux dimensions.
1. Écrire sur papier quelles sont les fonctionnalités désirées de notre librairie (faire valider par votre prof préféré).
2. Écrire les entêtes de fonctions.
3. Implémenter les fonctions (travail individuel).

---


## La force et la première loi de Newton

Le concept de *force* est intimement lié avec le concept de mouvement. Pourquoi un objet en mouvement change de direction? Pourquoi un objet accélère ou décélère? Pourquoi un objet arrêté se met en mouvement?

Intuitivement, une force est toute traction ou poussée exercée sur un objet. Quand vous faites vos courses et que vous mettez en mouvement votre chariot en le poussant, vous exercez une force dessus. Pour le mettre en mouvement vous devez combattre la *force de frottement* (une force dite de *contact*, car elle agit lors du contact de deux objet: ici le chariot et le sol). Quand vous soulevez votre pack de 6 bières du sol également. Cette fois vous devez compenser la *force de gravité* (qui n'est pas une force de contact).

Une force se mesure à l'aide d'un *dynamomètre* et ses unités sont les Newtons, notés $[\N]$.

De façon générale, lorsque vous devez mettre en mouvement un objet, vous faites passer sa vitesse de zéro à une vitesse non-nulle: vous produisez une accélération. De même lorsqu'un objet est en mouvement et que vous essayez de changer sa vitesse, que ce soit en *norme* ou en *direction*, vous devez à nouveau lui appliquer une force. Le fait que la modification de la vitesse (l'accélération) ait une norme et une direction, nous montre que la force est une quantité *vectorielle*. Nous pourrons donc utiliser toutes les méthodes de calcul vues au chapitre précédent.

En général il n'y a pas qu'une seule force qui peut s'appliquer sur un objet. 
Sur la @fig:box_force on a une situation *statique*. Une boîte est posée sur le sol et ne bouge pas. Comme vous avez pu vous en rendre compte dans votre vie de tous les jours, soulever ou porter une boîte (même légère) vous demande un certain effort, car elle pèse un certain *poids* (une force l'attire vers le sol). Lorsque la boîte est posée sur le sol, elle n'a pas soudainement perdu son poids et la force l'attirant vers le sol existe toujours. Le fait qu'elle ne bouge pas est dû au fait que le sol exerce une force égale en norme et opposée en direction sur la boîte. La somme des deux forces étant nulle, la boîte ne subit aucune accélération.

![Un système composé du sol et d'une boîte. La boîte exerce une force $\vec F$ sur le sol, le sol exerce la *même* force sur la boîte mais en direction opposée.](figs/box_force.svg){#fig:box_force width=40%}

Il y a deux concepts fondamentaux de ce que nous venons de discuter. Le premier est que plusieurs forces peuvent s'exercer sur un objet. La force *nette* s'appliquant ou force *résultante*, $\vec{F}_\mathrm{res}$ n'est autre que la somme de toutes ces forces. Si un objet subit l'action de $N$ forces, $\vec F_1$, $\vec F_2$, ..., $\vec F_N$, alors la force résultante s'écrira $$\vec F_\mathrm{res}=\vec F_1+\vec F_2+...+\vec F_N$$.

De ce que nous venons de discuter, nous déduisons qu'une force est présente que lorsqu'on *modifie* la vitesse d'un objet, en d'autres termes qu'on modifie son *accélération*. Il est important de noter que cette modification est une quantité *vectorielle* et qu'on peut modifier non seulement la norme, mais également la direction de la vitesse.

Cette constatation est la première loi de Newton, ou loi d'inertie, qui peut s'énoncer ainsi:

*Tout corps reste immobile ou conserve un mouvement rectiligne uniforme, tant que la somme des forces agissant sur lui sont nulles.*

En d'autres termes $$\vec{F}_1+\vec{F}_2+...\vec{F}_N=\sum_{i=0}^N\vec{F}_i=0.$$

---

Question (Bus) # 

Lorsque vous êtes dans le bus et que soudainement le chauffeur freine, vous êtes projetés vers l'avant. Quelle force est responsable de cette projection?

---

---

Réponse (Bus) #

Lorsque le bus freine, vous avez tendance à vouloir continuer de vous déplacer
en mouvement rectiligne uniforme. Ainsi, vous continuez votre route car aucune force n'est là pour vous retenir.

---

Dans ce chapitre nous nous intéressons à la *statique*. Les objets sont tous par définition dans un état *d'équilibre* et la somme de toutes les forces agissant sur un objet seront *nulles*. En d'autres terme la force résultante est toujours nulle
$$\vec F_\mathrm{res}=0.$$ 

---

Exemple (Tirer sur une corde) #

Soient deux personnes tirant sur une corde (voir @fig:corde). La personne en rouge applique une force $\vec F_2$ sur la corde et la personne en bleu applique une force $\vec F_1$ lorsque le système est à l'équilibre. Écrire la relation entre la force $\vec F_1$ et la force $\vec F_2$. Si la force $\vec F_1=\vectwo{10}{0}\ \N$, quelle sera la force $\vec F_2$?

Solution #

Comme la force comme le système est à l'équilibre cela signifie que la force résultante est nulle. On a donc 
$$\vec F_\mathrm{ref}=\vec F_1+\vec F_2=0.$$
On en déduit que 
$$\vec F_1=-\vec F_2.$$

![La personne en rouge applique une force $\vec F_2$ sur la corde et la personne en bleu la force $\vec F_1$.](figs/corde.svg){#fig:corde width=40%}

---

La situation d'équilibre ou non d'un système dépend évidemment des vecteurs de force qui y sont appliqués, mais également des *points d'action*: l'endroit où ces forces sont appliquées. Si nous considérons les deux situations de la @fig:point_action. Dans les deux cas nous avons une boîte qui ne bouge pas, puis nous appliquons les forces $\vec F_1$ et $\vec F_2$. Nous supposons que $\vec F_1=-\vec F_2$. Nous constatons que dans le premier cas, l'objet ne se met pas en mouvement (il reste dans un état d'équilibre car les forces s'annulent), alors que dans le deuxième, la boîte se met à tourner. La seule différence est le point d'application. En passant de l'application des forces des points $A$ et $B$, aux points d'application $C$ et $D$ nous avons changé l'état d'équilibre. L'équilibre dépend donc du point d'application des forces.

![Les force $\vec F_1$ et $\vec F_2$ ($\vec F_1=-\vec F_2$) sont appliquées sur la même boîte rectangulaire. La le cas du haut rien ne se passe, car les forces s'annulent. Dans le deuxième cas, la boîte va se mettre à tourner sur elle même (même si elle n'aura pas de mouvement de translation).](figs/point_action.svg){#fig:point_action width=60%}

Afin de déterminer si nous avons une situation d'équilibre il est utile définir la *ligne d'action* d'une force. La ligne d'action d'une force est la droite qui a la même direction que le vecteur de la force et qui passe par le point d'application de la force. Une illustration se trouve sur la @fig:ligne_action, où on voit les lignes d'actions pour les forces $\vec F_1$ et $\vec F_2$ (traitillés rouges et verts respectivement) dans le cas où elles sont alignées (haut) et où elles ne le sont pas (bas). Comme discuté précédemment lorsque les lignes d'action sont alignées, l'état d'équilibre est atteint et la boîte ne bougera pas. Dans le cas où les lignes d'action ne sont pas alignées, la boîte se mettra à tourner.

![Les force $\vec F_1$ et $\vec F_2$ et leurs lignes d'action respectivement en traitillés rouge et en vert.](figs/ligne_daction.svg){#fig:ligne_action width=60%}

On constate donc que pour se trouver dans un état d'équilibre, un système doit avoir non seulement des vecteurs de forces opposés, mais également agissant sur la même ligne d'action.

Afin de simplifier, nous considérons ici les objet comme n'étant que des *points matériels*. Comme les objets n'ont aucune étendue (ils sont de taille nulle), la condition d'équilibre s'écrit beaucoup plus simplement
$$\sum_{i=1}^N\vec F_i=\vec 0,$$
où $\vec F_i$ pour $i=1..N$ est l'ensemble des forces agissant sur le point matériel.
En d'autre termes, la force résultante sur le point doit être nulle.

---

Exemple (Tirer sur la corde: Plus on est de fous plus on rit) #

Soit la situation comme dans la @fig:corde_3. La norme des trois forces vaut respectivement $F_1=500\ \N$, $F_2=707\ \N$, et $F_3=966\ \N$. La situation est-elle en équilibre?

![Trois personnes tirent sur trois cordes qui sont attachées entre elles.](figs/corde_3.svg){#fig:corde_3 width=40%}

Solution #

Pour savoir si le système est à l'équilibre il faut savoir si la somme des trois force est nulle. Pour ce faire, on décompose les forces selon leur composantes cartésiennes
$$
\begin{aligned}
\vec F_1&=F_1\cdot\vectwo{\cos(45^\circ)}{\sin(45^\circ)}=F_1\cdot\vectwo{\cos(\pi/4)}{\sin(\pi/4)}=\vectwo{354}{354}\ \N \\
\vec F_2&=F_2\cdot\vectwo{\cos(120^\circ)}{\sin(120^\circ)}=F_2\cdot\vectwo{\cos(2\pi/3)}{\sin(2\pi/3)}=\vectwo{-354}{612}\ \N \\
\vec F_3&=F_3\cdot\vectwo{\cos(270^\circ)}{\sin(270^\circ)}=F_3\cdot\vectwo{\cos(3\pi/2)}{\sin(3\pi/2)}=\vectwo{0}{-966}\ \N  \\
\end{aligned}
$$
On peut à présent calculer la force résultante
$$\vec{F}_\mathrm{res}=\vec F_1+\vec F_2+\vec F_3=\vectwo{354-354+0}{354+612-966}=\vectwo{0}{0}\ \N.$$
On a donc que le système est en équilibre car la force résultante est nulle.

---

Un exercice comme le précédent, est en général une simplification d'un situation bien plus complexe. On peut imaginer la situation comme sur la @fig:caisse, où il s'agit de calculer la force que doivent appliquer les deux masses sur les côtés sur leur corde respective pour que la caisse soit à l'équilibre, sachant que la caisse exercice une force de $800\ \N$.

![Deux poids sont attachés à deux cordes, qui sont reliées à une troisième portant une boîte.](figs/caisse.svg){#fig:caisse width=40%}

Pour résoudre cette exercice il faut se rendre compte que la force se transmet le long des cordes. On a donc que le système peut se mettre dans une situation équivalente à celle de la @fig:corde_3. On a les trois forces qui s'appliquent à l'endroit où se rencontrent les trois cordes: au point $C$. On peut se ramener à la situation de la @fig:caisse_2.

![On peut ignorer tous les détails de notre problème et simplement ramener toutes les forces au points $C$.](figs/caisse_2.svg){#fig:caisse_2 width=40%}

Notre système est à l'équilibre si 
$$\vec F_{CA}+\vec F_{CB}+\vec F_{CD}=0.$$
Nous pouvons donc écrire
$$
\begin{aligned}
&F_{CA}\cdot\vectwo{\cos(130^\circ)}{\sin(130^\circ)}+F_{CB}\cdot\vectwo{\cos(30^\circ)}{\sin(30^\circ)}+\vectwo{0}{-800}=0,\\
&F_{CA}\cdot\vectwo{-0.643}{0.866}+F_{CB}\cdot\vectwo{0.766}{0.5}+\vectwo{0}{-800}=0.
\end{aligned}
$$
En résolvant ce système de deux équations à deux inconnues, on obtient
$$F_{CB}\cong522\ \N,\quad F_{CA}\cong 704\ \N.$$

## La deuxième loi de Newton

### La masse

Pour la suite du chapitre, il est important de définir le concept de *masse*. 
La masse d'un objet peut être vue comme la "quantité de matière" qu'il contient. 
Cette définition, bien que facilement compréhensible, n'est pas très précise. 

En fait la masse peut être vue comme un mesure de *l'inertie* d'un objet. C'est-à-dire que plus la masse d'un objet sera grande, plus la force nécessaire
pour changer sa vitesse (lui donner une certaine accélération) sera grande. Quand l'objet est au repose il sera difficile de le mettre en mouvement.
A l'inverse, plus sa vitesse sera grande, plus il sera difficile de l'arrêter. 

Comme vous le savez sans doute, la masse est mesurée en kilogrammes, ou $\kg$, en SI. 

Une voiture a une plus grande inertie qu'un balle de tennis de table: essayez de mettre en mouvement une voiture 
avec un raquette de ping-pong en tapant dessus, la voiture risque de ne pas bouger beaucoup. La masse de la voiture
est donc beaucoup plus élevée que celle de la balle.

Il est très important de ne pas confondre les concepts de *masse* et de *poids*. 
Comme nous venons de le discuter la masse est la quantité d'inertie d'un objet. Le poids est 
la *force* exercée par la gravité sur l'objet. Afin d'illustrer la différence, prenons l'exemple des astronaute qui
ont marché sur la lune. Vous avez sans doute tou·te·s vu·e·s la vidéo où ils font des sauts avec une grande facilité 
en portant une combinaison dont la masse est de près de $100\ \kg$ apparemment sans effort. Cela serait totalement impossible
sur terre. Leur masse est pourtant la même sur terre ou sur la lune. La différence se situe au niveau de la force qu'exercent 
la lune ou la terre sur un astronaute. En fait sur la lune la force gravitationnelle exercée sur un objet (son poids) est environ
six fois plus faible que sur la terre.

### Et cette deuxième loi alors?

La première loi de Newton nous dit qu'en absence de force résultante sur un objet, il restera au repos s'il était au repos,
ou s'il était en mouvement il continuera son mouvement avec la même vitesse en ligne droite.
En revanche, cela ne nous dit rien sur ce qui se passe quand une force est exercée sur l'objet.

A l'inverse, une force résultante exercée sur un objet va modifier sa vitesse dans la direction de la force: si la force est dans la direction du mouvement 
elle va changer la norme de la vitesse, si elle est perpendiculaire au mouvement elle va modifier uniquement sa direction.
Comme un changement de vitesse est une accélération, nous pouvons dire que l'effet d'une force sur un objet est de causer une accélération.
Il est très important de réaliser qu'une accélération, notée $\vec a$, est une quantité vectorielle et n'est pas uniquement la modification de la norme de la vitesse, mais représente toute modification du vecteur vitesse au cours du temps
$$\vec a=\frac{\Delta \vec v}{\Delta t},$$
où $\Delta \vec v=\vec v(t+\Delta t)-\vec(t)$ et $\Delta t$ est un intervalle de temps (voir la @fig:acc).

![L'accélération  $\vec a$ (en rouge) est une quantité vectorielle. Elle est la variation de la vitesse (qui est également une quantité vectorielle) au cours du temps. Sur cette figure la trajectoire (en bleu) d'un objet et deux vecteurs vitesse à des temps $t$ et $t+\Delta t$.](figs/acceleration_vect.svg){#fig:acc width=60%}

Comme on peut le voir sur la @fig:acc, bien que la vitesse ait la même norme (je vous le promets), il y a une accélération non nulle, car la vitesse a changé de direction au cours du temps. On peut en déduire qu'une force est appliquée sur l'objet.

Maintenant que nous savons que force et accélération sont des quantités reliées entre elles. Nous devons encore déterminer comment. 

Imaginons l'expérience suivante. Soit un chariot à roulettes posé sur un plan horizontal (négligeons les frottement). On tire le chariot avec une force horizontale et constante $\vec F_1$. On calcule son accélération en mesurant le temps, $t_1$, qu'il faut au chariot pour atteindre une certaine vitesse $\vec v$ (voir la @fig:acc_exp)
$$
\vec a_1=\frac{\vec v }{t_1}.
$$
On répète l'expérience en appliquant une force $\vec F_2=2\cdot \vec F_1$, $\vec F_3=3\cdot \vec F_1$, etc.

![On applique une force $\vec F_1$ (mesurée à l'aide d'un dynamomètre) sur le chariot et on mesure le temps qu'il faut au chariot pour atteindre une vitesse $\vec v$.](figs/acceleration_exp.svg){#fig:acc_exp width=40%}

Les résultats qu'on obtiendrait sont schématisés sur la @fig:acc_res. On voit que l'accélération est proportionnelle à la force: quand on double la force, on double l'accélération, quand on triple la force, on triple l'accélération, ... 

![L'accélération en fonction de la force. On voit qu'il y a une relation de proportionnalité entre les deux.](figs/acceleration_res.svg){#fig:acc_res width=40%}

Il nous manque encore la constante de proportionnalité. Comme nous l'avons discuté tout à l'heure la masse entre également en jeu. Quand on applique la même force sur deux objets, le plus léger accélérera plus que le plus lourd. Newton énonça sa deuxième loi comme suit:

*L'accélération d'un objet est proportionnelle à la force résultante qui lui est appliquée et inversement proportionnelle à sa masse. La direction de l'accélération est la direction de la force.*

On peut écrire cette loi sous forme mathématique comme
$$\vec a=\frac{\vec F_\mathrm{res}}{m}=\frac{\sum_{i=1}^N\vec F_i}{m},$$
où $\vec a$ est le vecteur accélération, $\vec F_\mathrm{res}$ la force résultante appliquée sur l'objet de masse $m$. On peut également écrire cette relation sous la forme plus familière en multipliant des deux côtés par $m$
$$\vec F_\mathrm{res}=m\cdot \vec a.$$

Si nous voulons l'écrire en composantes et en deux dimensions, l'équation ci-dessus devient
$$\vectwo{F_{x,\mathrm{res}}}{F_{y,\mathrm{res}}}=\vectwo{m\cdot a_x}{m\cdot a_y},$$
ou encore
$$\begin{aligned}
F_{x,\mathrm{res}}&=m\cdot a_x,\\
F_{y,\mathrm{res}}&=m\cdot a_y.
\end{aligned}$$
L'accélération ayant des unités de $[\m/\s^2]$ et la masse des $[\kg]$, les unités de la force sont $[\N]=[\kg\cdot\m/\s^2]$. On a donc qu'un Newton est la force qu'il faut appliquer sur un objet d'un kilogramme pour l'accélérer d'un mètre par seconde au carré.

---

Exemple (Ordres de grandeur) #

Quelle est la force requise pour accélérer une voiture de $1000\ \kg$ à $5\ \m/\s^2$ et une balle de $100\ \g$ à la même accélération.

Solution (Ordres de grandeur) #

De la seconde loi de Newton, on a que
$$\vec F_\mathrm{res}=m\cdot\vec a.$$
Comme la force agit dans la direction du mouvement, on peut considérer le problème comme unidimensionnel et donc ne s'intéresser qu'aux normes des vecteurs ci-dessus. Cette équation se réécrit donc
$$F_\mathrm{res}=m\cdot a.$$
Nous connaissaons dans les deux cas $a=5\ \m/s^2$ et $m_\mathrm{voiture}=1000\ \kg$ et $m_{balle}=0.1\ \kg$. On a donc
$$
\begin{aligned}
F_\mathrm{voiture}&=1000\cdot 5=5000\ \N,\\
F_\mathrm{balle}&=0.1\cdot 5=0.5\ \N.
\end{aligned}
$$

---

---

Exemple (Force pour arrêter une voiture) #

Soit une voiture de $1000\ \kg$ qui roule à $72\ \km/\h$. Conducteur freine pendant $5\ \s$ avec une force constante pour l'arrêter. 
Calculer la force nécessaire pour arrêter la voiture.

Solution (Force pour arrêter une voiture) #

La force est dans la même direction que le mouvement de la voiture. On peut donc considérer le problème comme unidimensionnel. 

La voiture roule à une vitesse de $v=72\ \km/h=20\ \m/\s$. La voiture passe de $20\ \m/\s$ à $0\ \m/\s$ en $5\ \s$, c'est-à-dire que son accélération est de
$$a=\frac{0-20}{5}=-4\ \m/\s^2.$$
La force est donc de 
$$F=m\cdot a=1000\cdot (-4)=-4000\ \N.$$
La force est négative, car elle est dans le sens opposé au mouvement de la voiture.

---

---

## La troisième loi de Newton 

Une force qu'on ressent toujours dans notre vie de tous les jours est la force de gravitation. Dans ce cas là, l'accélération est l'accélération gravitationnelle, notée $\vec g$ dont la norme à la surface de la terre est de $9.81\ \m/\s^2$ et qui est toujours dirigée vers le centre de la terre. Bien que cette force soit toujours présente, nous ne ressentons pas d'accélération lorsque nous sommes par exemples assis sur une chaise. 

---

Question # 

Que se passe-t-il donc?

---

---

Réponse #

Notre corps est soumis à la gravité. Il transmet cette force à la chaise sur laquelle nous sommes assis. En réaction, la chaise exerce une force égale en norme et opposée en direction à la force de gravité. 

---

Ce comportement se généralise à toute force, même lorsqu'une accélération est présente. Lorsqu'on plante un clou avec un marteau. La force que le marteau applique sur le clou, le marteau ressent une force égale en norme et opposée en direction appliquée par le clou.

Ce comportement a été décrit par Newton dans sa troisième loi:

*Lorsqu'un objet exerce une force sur un second objet, le second objet exerce une force égale en norme et de opposée en direction sur le premier.*

Si les objets sont notés $A$ et $B$, on a que la force de $A$ sur $B$, notée $\vec F_{AB}$ et celle de $B$ sur $A$, $\vec F_{BA}$ sont reliées par la relation
$$\vec F_{AB}=-\vec F_{BA}.$$

La troisième loi de Newton est aussi connue sous le nom du principe *d'action-réaction*.

Cette loi peut sembler contre intuitive dans un premier temps, mais en fait vous pouvez l'observer tous les jours. Lorsque vous appuyez sur une table avec votre main, vous voyez votre main se déformer, car la table exerce une force sur votre main. Plus vous appuierez fort, plus la déformation sera grande.

---

Question (Gravité) #

Lors d'un saut en chute libre, la force de gravité de la terre (qui est responsable de la chute libre) et la force de l'homme sur la terre sont égales et opposées. Dès lors, pourquoi est-ce l'homme qui tombe et non la terre qui se rapproche de l'homme?

---

---

Réponse (Gravité) #

En fait bien que la force soit égale et opposée, les objets, et en particulier leur masse, sont différents. Dans le cas de la chute libre, un homme pèse environ $80\ \kg$, alors que la terre a une masse d'environ $6\cdot 10^{24}\ \kg$. La force de gravité se calcule comme
$$\vec F_g=m\cdot \vec g,$$
où $\vec g$ est le vecteur d'accélération gravitationnelle, avec la norme de $\vec g$ de la terre qui est de 
$$g=9.81\ \m/\s^2.$$
On a donc que la norme de force gravitationnelle que ressent un humain en chute libre sur terre est de 
$$F_g=80\cdot 9.81\cong 800\ \N.$$
Cette force est égale et opposée à celle que ressent la terre. On peut donc calculer l'accélération résultant de cette force sur la terre
$$a_\mathrm{terre}=\frac{F_g}{m_\mathrm{terre}}=\frac{800}{6\cdot 10^{24}}\cong 1.3\cdot 10^{-22}\ \m/\s^2.$$
L'accélération de la terre est donc tellement faible qu'elle est complètement imperceptible.

---

Il existe beaucoup d'exemple où ce principe "d'action-réaction" est très utile. 

Une application très spectaculaire est la propulsion des fusées. Lors de son décollage les moteurs de la fusée éjectent une grande quantité de gaz: ils leur appliquent une force verticale dirigée vers l'arrière de la fusée (voir la @fig:rocket). Les gaz en contre-partie exercent une force dirigée vers l'avant fusée. C'est cette force qui est responsable de la propulsion de la fusée, et non une éventuelle force que la fusée exercerait sur le sol ou sur l’atmosphère (via les gaz éjectés). Ce processus est tout à fait similaire à ce qui se passe quand un ballon se dégonfle.

![Illustration de l'éjection de gaz d'une fusée qui est propulsée par la force de réaction des gaz sur la fusée. La force de la fusée sur les gaz $\vec F_{FG}$ vers l'arrière et la force de réaction des gaz sur la fusée $\vec F_{GF}$.](figs/rocket.svg){#fig:rocket width=40%}

Lorsque nous nous déplaçons à pieds c'est également la troisième loi de Newton qui fait que nous avançons. Avec nos pieds nous poussons sur le sol vers l'arrière. En réaction le sol pousse vers l'avant sur nos pieds, causant une accélération nette vers l'avant (voir la @fig:marche).

![Illustration de la marche à pieds. Nos pieds exercent une force vers sur le sol dirigée vers l'arrière (en bleu), $\vec F_{PS}$. Le sol exerce, lui une force vers l'avant sur nos pieds (en rouge), $\vec F_{SP}$ ce qui fait que nous sommes propulsés vers l'avant.](figs/marche.svg){#fig:marche width=30%}

Le même principe s'applique à plus ou moins tous les modes de propulsion: le patin à glaces, la voiture, etc. Il est donc très important de se souvenir de quel objet est originaire la force et à quel objet elle s'applique. Comme noté précédemment une force s'appliquant d'un objet $A$ sur un objet $B$ sera noté $F_{AB}$.

Reprenons l'exemple de la marche. D'après la troisième loi de Newton $\vec F_{PS}=-\vec F_{SP}$. Hors on sait que 
$$\vec F_\mathrm{res}=\sum_i \vec F_i.$$ 
On aurait tendance à dire que la force résultante sur le marcheur est 
$$\vec F_{PS}+\vec F_{SP}=0.$$ 
Ce raisonnement est évidemment faux (on sait d'expérience que lorsque nous marchons nous avançons...). EN fait pour calculer la force résultante sur un objet, il faut faire la somme des force agissant *sur* l'objet et ne pas compter celles qu'il applique sur d'autres. Dans le cas du marcheur, on a donc que 
$$\vec F_\mathrm{res}=\vec F_{SP}.$$

---

Problème (Pousser un tonneau) #

Soit un tonneau posé sur le sol. On aimerait savoir quelle force une personne doit appliquer sur le tonneau pour le déplacer en le poussant (voir @fig:tonneau)?

1. Écrire toutes les forces en présence, avec l'origine et la cible de chaque force.
2. Calculer le bilan des forces agissant sur chaque objet.
3. Déterminer la force minimale à appliquer pour mettre en mouvement le tonneau.

![Schéma d'une personne poussant un tonneau.](figs/tonneau.svg){#fig:tonneau width=30%}

---

---

Question  (Accident) #

Un gros camion entre en collision frontale avec une petite voiture de sport. 

1. Quelle est la voiture qui va ressentir la plus grande force?
2. Quelle est la voiture qui va ressentir la plus grande accélération?
3. Quelle sont les de Newton qui vont nous aider à trouver les réponses à ces questions?

---

---

Réponse  (Accident) #

Un gros camion entre en collision frontale avec une petite voiture de sport. 

1. Les deux ressentent la même force.
2. La voiture de sport.
3. Respectivement la troisième et la deuxième.

---

## Applications des lois de Newton

Dans cette section, nous allons mettre en pratique les lois de Newton que nous venons de voir.

---

Exemple (La boite) #exemple:boite

Soit une boîte de masse $m=1\ \kg$ posée sur une table et ne bougeant pas. 

1. Déterminer son poids et calculer la force exercée sur la boîte par la table.
2. On appuie sur la boîte avec une force de $10\ \N$. Quelle est la force exercée par la table sur la boîte?
3. On tire avec une force de $5\ \N$ en direction verticale sur la boîte. Quelle est la force exercée par la table sur la boîte?
4. On tire avec une force de $20\ \N$ en direction verticale sur la boîte. Quelle est la force exercée par la table sur la boîte?
5. Quelle est l'accélération de la boîte dans la situation 4?

Solution (La boite) #

Sur la @fig:boite_exo on voit un schéma pour les parties 1 à 4. 

![Schéma des quatre situation de l'@exemple:boite.](figs/boite_exo.svg){#fig:boite_exo width=30%}

1. La masse de la boîte étant de $1\ \kg$, on a que son poids est de 
$$F_g=1\cdot (-9.8)=- 9.8\ \N.$$
Comme la boîte ne subit pas d'accélération, on en déduit que la force résultante agissant sur elle
$$F_g+F_t=0\Leftrightarrow F_g=-F_t,$$
où $F_t$ est la force de la table sur la boîte. On a donc que 
$$F_t=9.8\ \N.$$
2. On applique une force externe, $F_e=-10\ \N$ sur la boîte. La boîte ne bougeant toujours, on en déduit que la force résultante doit rester nulle
$$
\begin{aligned}
0&=F_g+F_t+F_e,\\
F_t&=-F_e-F_g,\\
F_t&=10+9.8=19.8.
\end{aligned}
$$
La boîte apparaît donc plus lourde à la table. Coïncidence? Je ne crois pas.
3. Lorsqu'on tire la boîte vers le haut avec une force de $F_e=5\ N$, on ne tire pas assez fort pour soulever la boîte. Elle va donc rester en contact avec la table.
La boîte ne bougeant toujours pas, la force résultante sur la boîte doit être nulle
$$
\begin{aligned}
0&=F_g+F_t+F_e,\\
F_t&=-F_e-F_g,\\
F_t&=-5+9.8=4.8.
\end{aligned}
$$
La boîte apparaît donc plus légère à la table. Coïncidence? Je ne crois pas.
4. Cette fois la force appliquée à la boîte est plus élevée que son poids. Ainsi, on va pouvoir soulever la boîte. La table n'exercera plus aucune force sur la boîte.
5. Lorsqu'on tire la boîte vers le haut avec une force de $F_e=20\ N$, on tire assez fort pour soulever la boîte. On aura donc une force résultante non nulle.
Cette force sera de
$$
\begin{aligned}
F_\mathrm{res}&=F_g+F_e,\\
F_\mathrm{res}&=-9.8+20=10.2\ \N.
\end{aligned}
$$
On peut dès lors calculer l'accélération de la boîte grâce à la deuxième loi de Newton
$$
\begin{aligned}
F_\mathrm{res}&=m\cdot a,\\
a&=\frac{F_\mathrm{res}}{m}=\frac{10.2}{1}=10.2\ \frac{\m}{\s^2}.
\end{aligned}
$$

---

---

Exercice (Changement de poids dans un ascenseur) #

Une personne se trouve dans un ascenseur à l'arrêt. Elle est debout sur une balance indiquant qu'elle pèse $70\ \kg$.
L'ascenseur démarre et commence à monter avec une accélération constante de $2\ \m/s^2$ pendant une seconde puis continue à vitesse constante. 

1. Faire un croquis de la situation avec les forces présentes.
2. Quelle est le poids de la personne pendant la phase d'accélération? (Qu'indique la balance?)
3. Qu'indique la balance après la phase d'accélération, lorsque l'ascenseur va à une vitesse de $2\ \m/\s$?

---

Jusqu'ici, nous ne nous sommes intéressés principalement qu'à des problèmes unidimensionnels impliquant 
les lois de Newton ce qui simplifie beaucoup leur traitement mathématique. 

---

Exemple #exemple:oblique

Considérons une boîte de masse $m=10\ \kg$ posée sur le sol sur laquelle une corde est attachée. On essaie de tirer la boîte avec une force $\vec F$ à l'aide de la corde 
qui formera un angle $\theta=30^\circ$ avec le sol (voir la @fig:boite_oblique). De plus, il existe une force de frottement horizontale qui s'oppose au mouvement de la boîte, $\vec F_\mathrm{frot}$. 

1. Calculer la force minimale qu'on doit fournir pour faire bouger la boite si la force de frottement est de $10\ N$. 
2. Quelle est la force minimale à fournir pour décoller la boite du sol?

![Une boite oblique avec une force de frottement.](figs/boite_oblique.svg){#fig:boite_oblique width=30%}

Solution #

Le bilan des force présentes peut s'écrire
$$\vec F_\mathrm{res}=\vec F+\vec F_\mathrm{frot}+\vec F_g.$$
Les composantes de la force $\vec F$ peuvent s'écrire
$$\vec F=\vectwo{F\cos(\theta)}{F\sin(\theta)}.$$

1. La force minimale pour que la boite commence à bouger horizontalement est le $F$, tel que
$$F_{\mathrm{res},x}=0,$$
autrement soit dit il faut résoudre l'équation
$$
\begin{aligned}
&F\cos(\theta)-F_{\mathrm{frot},x}=0,\\
&F=\frac{F_{\mathrm{frot},x}}{\cos(\theta)}=11.5\ \N.
\end{aligned}
$$

2. Afin de de soulever la boite il est nécessaire que la composante $y$ de la force résultante soit nulle.
En d'autre termes que la composante vertical de $\vec F$ contrebalance exactement la force de gravité $F_g$
$$
\begin{aligned}
&F\sin(\theta)-F_g=0,\\
&F=\frac{F_g}{\sin(\theta)}=196\ \N.
\end{aligned}
$$

---

## Problèmes couplés

Lorsque plus d'un corps est présent dans un problème, on a à faire à un *système couplé*. 
Il s'agira alors en général de résoudre un système d'équations. 
Nous allons illustrer ce genre de situations
avec l'exemple suivant

Exemple (Deux boites) #

Soient deux boites, notées $A$ et $B$, reliées par une corde, comme dans la situation 
de la @fig:deux_boites. Les boites ont des masses respectives de $m_A=10\ \kg$ et $m_B=20\ \kg$.
Une force horizontale est appliquée sur la boite $A$, $F_h=50\ \N$. 

![Deux boites reliées par une corde.](figs/deux_boites.svg){#fig:deux_boites width=40%}

1. Calculer l'accélération de chaque boite.
2. La tension dans la corde qui relie les boites.

Solution (Deux boites) #

Lorsque nous tirons sur la boite $A$ une force de tension, $\vec F_t$, se crée dans la corde reliant les deux boites. 
Cette force sera dirigée vers la droite pour la boite $B$ et vers la gauche pour la boite $A$. Selon le principe 
d'action-réaction, ces deux forces sont égales en norme et opposée en direction. Le mouvement étant uniquement horizontal, 
les forces normales (les force de gravité et les réactions de la table: $\vec F_{g,A}, \vec F_{NA}, \vec F_{g,B}, \vec F_{NB}$) 
n'entrent pas en ligne de compte pour cet exercice.

1. Nous pouvons à présent faire le bilan des forces horizontales. Sur la boite $A$, nous avons 
$$F_h-F_t=m_A\cdot a_A,$$
alors que pour la boite $B$, nous avons
$$F_t=m_B\cdot a_B.$${#eq:sec_force}
Comme les boites sont connectée et que nous négligeons tout effet élastique dans la corde, les deux accélérations seront égales
$a_A=a_B=a$. On a donc deux équations à deux inconnues à résoudre (nous ne connaissons pas $a$ et $F_t$. 
En additionnant les deux équations ci-dessus on a
$$
\begin{aligned}
F_h=m_A\cdot a+m_B\cdot a=(m_A+m_B)\cdot a,\\
50=30\cdot a,\\
a=5/3\ \m/s^2.
\end{aligned}
$$
2. En substituant à présent ce résultat dans l'@eq:sec_force, on obtient la tension
$$F_t=m_B\cdot a=20\cdot \frac{5}{3}=\frac{100}{3}\ \N.$$


### Forces de frottement

Dans l'@exemple:oblique, nous avons considéré une force de frottement agissant sur une boîte alors que nous l'avons négligé 
dans tous autres exemples. Dans la plupart des situation les corps sont soumis à des forces de frottement.
Il existe beaucoup de forces de frottement de nature différentes et nous allons en discuter quelques une ici. 

### Force de frottement cinétique

Ici, nous allons nous concentrer d'abord sur les forces 
de frottement *cinétiques* qui s'applique sur les objets glissant sur une surface. Elles sont dues à la nature rugueuses
de la surface de contact entre un objet et une surface.

Lorsqu'un objet glisse sur une surface, la force de frottement cinétique agit dans la direction opposée au mouvement. 
La norme de la force dépend de la nature de la surface et de l'objet. Elle dépend de la force normale de la surface sur
l'objet (également appelé poids apparent de l'objet). Lorsqu'on glisse un objet sur une surface il y a donc 4 forces en jeu (voir la @fig:frot_cin).
Le poids de l'objet, $\vec F_g$, la force avec laquelle on glisse l'objet, $\vec F$, le poids apparent, $\vec F_N$, et la force de frottement $\vec F_\mathrm{frot}$. 
Dans le modèle que nous considérons ici la force de frottement ne dépend pas de la surface de contact entre l'objet et le sol.

![Une boite glissant sur une surface tirée par une force $\vec F$, qui a une force de gravité $\vec F_g$ et une force normale $\vec F_N$, 
et une force de frottement $\vec F_\mathrm{frot}$. Même si les surfaces ont l'air complètement lisses au niveau microscopique elles ne le sont pas.](figs/frot_cin.svg){#fig:frot_cin width=40%}

Une relation phénoménologique relie la norme de $F_N$ et $F_\mathrm{frot}$
$$F_\mathrm{frot}=\mu_k F_N,$$
où $\mu_k$ est le coefficient de frottement cinétique[^5]. 

---

Remarque #

Il est important de noter que cette équation n'est *pas* vectorielle, car la force de frottement et la force normale sont perpendiculaire l'une avec l'autre.

---

Le coefficient de frottement dépend évidemment des deux surfaces qui sont en contact, si elles sont mouillées, si elles ont été polies ou non, etc.
Mais dans ce contexte $\mu_k$ ne dépend pas de la vitesse de l'objet, ni de la surface de contact.


### Force de frottement statique

Nous avons d'abord considéré la force de frottement cinétique entre un objet *en mouvement* et une surface. Lorsque l'objet n'est pas en mouvement
cette force est différente et s'appelle la force de *frottement statique*. Comme l'objet n'est pas en mouvement il ne peut y avoir de force de frottement 
cinétique. Lorsque vous essayez de déplacer une grosse armoire mais quelle refuse de bouger alors que vous poussez dessus, cela signifie qu'une autre force doit être présente qui empêche le mouvement. Lorsque finalement, vous 
appliquez une force suffisante, vous arrivez à débloquer 
la situation: à vaincre la force de frottement statique maximale et l'armoire se met à glisser. 

La force de frottement statique maximale s'exprime de façon similaire à la force de frottement cinétique
$$F_\mathrm{frot,max}=\mu_s\cdot F_N,$$
où $\mu_s$ est le coefficient de frottement statique[^6]. On a donc que la force de frottement statique est 
$$F_\mathrm{frot}\leq\mu_s\cdot F_N.$$

Vous avez sans doute remarqué qu'une fois que nous avons réussi à mettre en mouvement la fameuse grosse armoire, 
il est plus simple de continuer à la faire glisser. 
Ceci est dû en général au fait que le coefficient de frottement statique est plus grand que le coefficient de frottement cinétique.

Si on se place dans la situation de la @fig:frot_stat et qu'on fait varier la force $\vec F$ avec laquelle on essaie de déplacer la boîte
et qu'on mesure la force de frottement, il y a 2 comportement différents (voir la @fig:frot_force_appliquee). Dans un premier temps quand 
$\vec F<\vec F_\mathrm{frot,max}$, on a que $\vec F=-\vec F_\mathrm{frot}$. Puis une fois le seuil de la force de frottement statique maximale 
dépassé, l'objet se met en mouvement, et la force la force de frottement statique est remplacée par la force de frottement cinétique, 
ce qui a souvent comme effet de diminuer la force de frottement.

![Une boite surface tirée par une force $\vec F$, qui a une force de gravité $\vec F_g$ et une force normale $\vec F_N$, 
et une force de frottement $\vec F_\mathrm{frot}$.](figs/frot_stat.svg){#fig:frot_stat width=40%}

![La force de frottement, $\vec F_\mathrm{frot}$, en fonction de la force appliquée pour mettre en mouvement la boîte, $\vec F$.](figs/frot_force_appliquee.svg){#fig:frot_force_appliquee width=40%}

---

Exemple (Frottement statique/cinétique) #

Soit le cas dessiné à la @fig:frot_stat. On pose une boite de $m=10\ \kg$ sur un sol horizontal. 
Les coefficients de frottement cinématiques et statiques sont donnés par $\mu_k=0.3$ et $\mu_s=0.4$.
Déterminer la force de frottement et l'accélération de la boîte si la force $\vec F$ est égale à $0\ \N$, $10\ \N$, $20\ \N$, $38\ \N$, et $40\ \N$.

Solution (Frottement statique/cinétique) #

La force statique maximale est donnée par
$$F_\mathrm{frot,max}=\mu_s\cdot F_N=0.4\cdot 10\cdot 9.8=39.2\ \N.$$
Les 4 premières force ci-dessus seront donc inférieures à ce seuil et la force de frottement sera 
$-\vec F$ grâce à la deuxième loi de Newton. Lorsque $\vec F$ dépasse $39.2\ \N$, la force de frottement devient la force de frottement cinétique.
On a donc 
$$F_\mathrm{frot}=\mu_k\cdot F_N=0.3\cdot 10\cdot 9.8=29.4\ \N.$$
On a donc qu'on a une force résultante non-nulle sur la boite 
$$F_\mathrm{res}=F-F_\mathrm{frot}=40-29.4=10.6\ \N.$$
Et donc la boite va accélérer avec un accélération
$$a=F_\mathrm{res}/m=10.6/10=1.06\ \m/\s^2.$$

---

---

Question (Luge) #

Est-il plus facile de pousser ou de tirer une luge? Pourquoi?

---

---

Réponse (Luge) #

Tirer la luge, car lorsque nous poussons nous avons tendance à "enfoncer" la luge dans le
sole et donc augmenter le frottement. A l'inverse quand on tire la luge,
on a tendance à la soulever et donc à diminuer le frottement.

---

Exemple (Plan incliné) #

Afin de complexifier un peu plus encore les cas d'application de la force de frottement considérons le cas
du plan incliné (voir la @fig:plan_incline). Soit une boite de masse $m$ posée sur un plan incliné qui forme un angle 
$\theta$ avec l'horizontale. La force de gravité agit toujours dans la direction verticale, alors qu'ici la force normale du plan sur la boite n'est pas 
verticale mais est perpendiculaire au plan incliné. On aura donc que le frottement sera plus faible que lorsque le plan est horizontal, 
car la composante verticale de la force normale sera plus faible. Calculer l'accélération de la boite si le coefficient de frottement cinétique
est de $\mu_k=0.1$.

![Une boite de masse $m$ posée sur un plan incliné. Les axes sont alignés sur la tangente et la normale du plan.](figs/plan_incline.svg){#fig:plan_incline width=40%}

Solution (Plan incliné) #

Il est plus simple de placer les axes parallèle et normal au plan. Ainsi la force de gravité sera la seule qui ne sera pas alignée sur un des axes.
Nous avons donc que la force de gravité est donnée par
$$
\vec F_g=\vectwo{mg\sin\theta}{-mg\cos\theta}.
$$
Dans la direction $x$, le bilan de force est donné par
$$
\begin{aligned}
&F_{g,x}-F_{\mathrm{frot},x}=ma_x,\\
&mg\sin\theta-F_N\mu_k=ma_x,\\
&mg\sin\theta-F_N\mu_k=ma_x.
\end{aligned}
$${#eq:first_incline}
Afin de résoudre cette équation, il nous manque $F_N$. Regardons la composante $x$ de la force
$$
\begin{aligned}
&F_{g,y}+F_N=ma_y=0,\\
&-m g\cos\theta+F_N=0,\\
&F_N=mg\cos\theta.
\end{aligned}
$$
En remplaçant cette relation dans l'@eq:first_incline on obtient
$$
\begin{aligned}
&mg\sin\theta-mg\cos\theta\mu_k=ma_x,\\
&g(\sin\theta-\cos\theta\mu_k)=a_x,\\
&a_x=9.8\cdot(\sin(30)-0.1\cdot \cos(30))=4.05\ \m/\s^2.
\end{aligned}
$$

Il existe beaucoup d'autres types de forces de frottement. Elles sont pour la plupart responsables
du mauvais rendement de la plupart de nos appareils d'utilisation quotidienne ou de nos moyens de transports.
Néanmoins les forces de frottement sont également nécessaires pour nos déplacements. Sans la force de frottement
nous ne pourrions pas marcher. Il suffit de voir la difficulté à se déplacer quand nous nous trouvons sur une surface très glissante 
(où la force de frottement est très faible).

### Frottement visqueux

L'autre frottement auquel nous avons à faire au quotidien est le frottement visqueux. Il apparaît 
lorsque deux solides sont mis en contact via un lubrifiant ou qu'un corps est en mouvement dans un fluide.

Si nous considérons le mouvement d'un objet dans un fluide. En première approximation, la force de frottement 
est proportionnelle à la vitesse de l'objet et dans le sens opposé du mouvement
$$
\vec F_\mathrm{frot}=-k\cdot \vec v,
$$
où $k$ est coefficient de résistance de l'objet dans le fluide. Il dépend de la forme de l'objet, 
de la viscosité du fluide, ainsi que de la facilité de l'objet à pénétrer dans le fluide.

Lorsqu'un objet tombe en chute libre dans l'air, il ne va pas accélérer indéfiniment. 
Au fur et à mesure que sa vitesse augmente la force de frottement va augmenter jusqu'à
être égale en norme à la force de gravité. La force résultante sur l'objet devenant nulle, 
il n'y aura plus d'accélération et la vitesse restera constante. On appelle cette vitesse la vitesse limite.

On peut la calculer à l'aide de la deuxième loi de Newton
$$
\begin{aligned}
F_\mathrm{frot}-F_g=0,\\
k v_\mathrm{lim}-m g=0,\\
v_\mathrm{lim}=\frac{m g}{k}.
\end{aligned}
$$

---

Exemple (Le parachutiste) #

Calculer la vitesse limite d'un parachutiste de masse de $m=80\ \kg$ si son coefficient de résistance est de
$k=10 \kg/\s.$

Solution (Le parachutiste) #

La vitesse limite se calcule à l'aide de la formule précédente
$$
v_\mathrm{lim}=\frac{80\cdot 9.8}{10}=78.4\ \m/\s=282\ \km/\h.
$$

---

---

## Questions

1. Si une personne se tient sur un skateboard à l'arrêt. Pourquoi tombe-t-elle vers l'arrière si on pousse soudainement le skate vers l'avant?
2. Si un objet est en mouvement, est-il possible que la force résultante sur l'objet soit nulle?
3. Si l'accélération d'un objet est nulle, est-ce que cela veut dire qu'il n'y a aucune force qui agit sur l'objet?
4. Si une seule force agit sur un objet. Peut-il avoir une accélération nulle? Une vitesse nulle?
5. Si un objet est suspendu à une petite cordelette et on attache une seconde cordelette à ce même objet et on la laisse pendre. Si on tire d'un coup sec
sur la seconde cordelette une des deux va se rompre. Laquelle a le plus de chance de se casser?
6. La force de gravité sur un caillou de $2\ \kg$ est supérieure à celle d'un caillou de$1\ \kg$. Pourquoi alors les deux tombent-ils à la même vitesse?
7. On tire une boite posée sur un plan horizontal avec une force parallèle au plan et on néglige les frottements. Si maintenant on tire la boite avec un certain angle est-ce que l'accélération 
sera plus élevée, plus faible, la même? Que se passe-t-il s'il y a une force de frottement?
8. Pourquoi est-ce que la distance de freinage d'un train est plus longue que celle d'une voiture allant à la même vitesse?

---


---

Travail pratique (Calcul de force résultante) #

Générer un tableau contenant $N$ particules, numérotées $p_i$, représentées par leur masse $m_i$
et leur position $\vec r_i$, sachant que:

* La position des particules est aléatoire dans le domaine $[0, 10]\times[0, 10]\m^2$.
* La masse des particules est aléatoire dans le domaine $[0,10]\kg$.

1. Calculer la force résultante dûe à l'attraction gravitationnelle sur chaque particule

    $$
    \vec F_i = \sum_{j=1,j\neq i}^N\vec F_{ij},
    $$
    où $\vec F_{ij}$ est la force gravitationnelle entre la particule $i$ et la particule $j$, et est donnée par
    $$
    \vec F_{ij}=-G\frac{m_i m_j}{||\vec r_{ij}||^3}\vec r_{ij},
    $$
    où $\vec r_{ij}$ est le vecteur reliant la particule $i$ à la particule $j$, $G=6.67\cdot 10^{-11}\ \m^3/(\kg\cdot \s^2)$
    est la constante universelle de gravitation.
2. Si chaque particule, $p_i$, a de plus une vitesse $\vec v_i$, calculer la force résultante sur chaque particule si $k=10 \kg/\s$ ($k$ est le coefficient de résistance de l'objet dans le fluide).
3. Calculer ces forces si le domaine est périodique, c'est à dire si $x+10=x$ et $y+10=y$.
4. Utiliser la librairie `SDL2` pour afficher les particules à l'écran (un pixel blanc par particule).

---

## Les équations du mouvement

Les lois de Newton, nous permettent de décrire des systèmes très complexes, comme le déplacement des planètes
dans le système solaire, ou les gaz de particules. Dans cette section nous allons voir
comment.

Pour ce faire, nous allons considérer une particule $P$ en mouvement, qui est caractérisée par une position
$\vec r(t)$ (qui dépend donc du temps, $t$) et par une masse $m$ constante. Nous souhaitons ici décrire le mouvement
de $P$ en fonction du temps, en d'autre termes la valeur de $x(t)$ pour toute valeur de $t$.
Il existe différents cas de figures, tels que mouvement rectiligne uniforme, ou le mouvement réctiligne uniformément
accéléré, que vous connaissez qui permettent de résoudre exactement le mouvement de $P$. Ici, nous souhaitons
généraliser un petit peu tout ça, en supposant que la vitesse et l'accélération de la particule dépendent
également du temps, $\vec v(t)$ et $\vec a(t)$. Pour les besoins de ce cours, nous allons utiliser des
*approximations* numérique des valeurs de $x(t)$, $v(t)$, et $a(t)$.

Pour simplifier, nous allons *discrétiser* le temps. Au lieu de laisser le temps prendre n'importe quelle
valeur réelle positive, $t\in\real^+$, il ne pourra prendre que les valeurs suivantes:
$$
t_j=j\cdot \delta t,
$$
$\delta t>0$ étant le pas de discrétisation temporel et $j\in\integer^+$ (voir @fig:time_discr).

![Illustration de la discrétisation temporelle.](figs/time_discr.svg){#fig:time_discr}


### Le mouvement sans accélération

Supposons que pour notre particule $P$, nous connaissons sa position initiale, $\vec r(0)$ et sa vitesse
en tout temps, $\vec v(t)$. Nous souhaitons connaître une approximation de la position $\vec r(t_j)$.
Pour ce faire nous commençons au point $\vec r(0)$ et calculons sa nouvelle position
à l'aide de la vitesse $\vec v(0)$
$$
\vec r(\delta t)=\vec r(0)+\delta t\cdot \vec v(0).
$$
Plus $\delta t$ est petit, plus cette approximation sera précise.
En utilisant la notation $t_j=j\cdot \delta t$, on obtient
$$
\vec r(t_1)=\vec r(t_0)+\delta t\cdot \vec v(t_0).
$$

---

Remarque ($\delta t\rightarrow 0$) #

On peut réécrire l'équation ci-dessus comme
$$
\vec v(0)=\frac{\vec r(\delta t)-\vec r(0)}{\delta t}.
$$
En prenant la limite $\delta t\rightarrow 0$, on obtient
$$
\vec v(0)=\vec r'(0),
$$
Soit la relation bien connue que la dérivée de la position donne la vitesse.
Ou encore de façon similaire
$$
\vec v(t_0)=\vec r'(t_0),
$$

---

Nous pouvons ainsi calculer la position pour $t_2$[^7]
$$
\vec r(t_2)=\vec r(t_1)+\delta t\cdot \vec v(t_1),
$$
et ainsi de suite pour n'importe quelle valeur de $t_j$
$$
\vec r(t_j)=\vec r(t_{j-1})+\delta t\cdot \vec v(t_{j-1}).
$$
De cette équation, nous pouvons également déduire que
$$
\vec v(t_{j-1})=\frac{\vec r(t_j)-\vec r(t_{j-1})}{\delta t},
$${#eq:vt0}
ou encore 
$$
\vec v(t_{j})=\frac{\vec r(t_j+1)-\vec r(t_{j})}{\delta t}.
$${#eq:vt1}

Nous pouvons ainsi approximer le mouvement de la particule $P$
pour tout instant $t_j$. A l'inverse en connaissant la position de la
particule à tous les $t_j$, nous pouvons calculer sa vitesse.

### Le mouvement avec accélération

De façon similaire à ce que nous avons fait pour le lien entre la position et
la vitesse, nous pouvons faire le lien entre l'accélération et la vitesse.
En connaissant la vitesse de la particule $P$ à tout instant $\vec v(t_j)$,
nous pouvons approximer l'accélération $\vec a(t_j)$ comme
$$
\vec a(t_j) = \frac{\vec v(t_j)-\vec v(t_{j-1})}{\delta t}.
$$
En utilisant l'@eq:vt0 et l'@eq:vt1, il vient
$$
\vec a(t_j) = \frac{\frac{\vec r(t_j+1)-\vec r(t_{j})}{\delta t}-\frac{\vec r(t_j)-\vec r(t_{j-1})}{\delta t}}{\delta t}=\frac{\vec r(t_{j+1})-2\vec r(t_j)+\vec r(t_{j-1})}{\delta t^2}.
$$
En isolant $\vec r(t_{j+1})$ il vient
$$
\vec r(t_{j+1})=2\vec r(t_j)-\vec r(t_{j-1})+\vec a(t_j)\delta t^2.
$$
Cette formule est correcte pour $j\geq 1$. Pour $j=0$, on a
$$
\vec r(t_{1})=\vec r(t_0)+\delta t\vec v(t_0)+\vec a(t_0)\delta t^2.
$$
Il est donc nécessaire de connaître la vitesse initiale et la position
initiale de la particule $P$ pour pouvoir calculer son évolution,
ainsi que son accélération en tout temps $t_j$. Afin de calculer
l'accélération de la particule $P$, on utilise souvent les 
lois de Newton. Ainsi,
$$
\vec a(t_j)=\frac{\vec F(t_j)}{m}.
$$

---

Travail pratique (Mouvement des particules) #

1. Implémenter le mouvement des particules en utilisant les formules ci-dessus.
2. Implémenter les fonctions permettant d'initialiser un tableau de particules avec une position $\vec r$, une masse $m$, et une $\vec v$ donnée (attention, la vitesse doit être cohérente avec celle de l'@eq:vt0).
3. Créer une galaxie avec un "trou noir" en son centre (il a une masse très très très grande par rapport au reste) et des étoiles tournant autour qui ont des positions et des masses aléatoires. En déduire leurs vitesses pour qu'elles "tournent" autour du trou noir sans s'en rapprocher (elles sont en orbite autour).

---
