# Le potentiel électrique

Tout comme pour le mouvement le concept *d'énergie* est très
important pour l'électricité. Il permet d'étendre le concept
de **conservation de l'énergie** à d'autres domaines qu'à la cinématique ou la dynamique.

## L'énergie potentielle électrique

Comme dans le cas de l'énergie mécanique, on va définir l'énergie potentielle électrique
comme on le ferait pour une force conservative. Le travail d'une force conservative entre deux points ne dépend pas
du chemin parcouru mais uniquement du point de départ et du point d'arrivée. Dans le cas
de l'énergie potentielle dûe à la force de gravité, on a que $E=m\cdot g\cdot h$ (avec $m$ la masse, $h$
la hauteur et $g$ l'accélération gravitationnelle). On sait grâce à la loi de Coulomb
que la force entre deux charges est donnée par
\begin{equation*}
F=k\frac{Q_1Q_2}{r^2}.
\end{equation*}
Comme pour l'énergie mécanique, on définit l'énergie potentielle d'un objet chargé qui se déplace entre 2 points,
$A$ et $B$ (voir @fig:epot)
comme
$$
\Delta_{EP}(A,B)=-W_{A\rightarrow B},
$$
où $\Delta_{EP}(A,B)$ est la variation d'énergie potentielle
entre les points $A$ et $B$, et $W(A\rightarrow B)$ le travail du à la force
électrostatique. Ici, le travail $W(A\rightarrow B)>0$ et donc la charge
va perdre de l'énergie potentielle.

![Le transport d'une charge positive entre $A$ et $B$ entre deux plaques chargées infinies.](figs/epot.svg){#fig:epot width=50%}

La variation d'énergie potentielle s'écrit donc
$$
\Delta_{EP}(A\rightarrow B)=E_\mathrm{pot}(B)-E_\mathrm{pot}(A).
$$
Quand une charge $q$ bouge d'un point $A$ à un point $B$ son énergie augmente
(ou diminue) comme l'inverse du travail qu'il faut à la force électrostatique
pour la déplacer de $A$ à $B$.

Ainsi Dans le cas de @fig:epot, nous sommes dans une situation où on a un
champs électrique uniforme $E$ entre deux plaques infinies.
Si on lâche la charge $q$ du point $A$,
et qu'on suppose que $q$ est suffisamment petite pour ne pas modifier
le champs électrique entre les plaques. La force électrostatique va déplacer
la charge du point $A$ au point $B$ sur une distance $d=|A-B|$ et effectuer un travail $W$
$$
W_{A\rightarrow B}=F\cdot d=q\cdot E\cdot d.
$$
Le changement d'énergie potentielle est donc
$$
E_\mathrm{pot}(B)-E_\mathrm{pot}(A)=-q\cdot E\cdot d.
$${#eq:epot}
L'énergie potentielle diminue dans ce cas (le travail est positif)
et la particule accélère naturellement du point $A$ au point $B$.
Ainsi la loi de conservation d'énergie est vérifiée:
l'énergie cinétique augmente et l'énergie potentielle (électrique) diminue
d'autant. A l'inverse si on remplace la charge $q$ par $-q$
son énergie potentielle sera augmentée lors du déplacement
de $A$ à $B$.

---

Question (Unités) #

Quelles sont les unités de l'énergie potentielle électrique?

---

---

Réponse (Unités) #

Comme pour toute énergie, les unités sont des joules, $[J]$, soit des
$$
[J]=[\mathrm{N}\cdot \mathrm{m}]=\left[\mathrm{kg}\cdot \frac{\mathrm{m}^2}{\mathrm{s}^2}\right].
$$

---

Il est important de noter que la valeur de l'énergie potentielle est relative à une valeur de référence.
En effet, comme on le voit à l'@eq:epot, on ne définit
que la différence d'énergie potentielle et pas
une valeur absolue. En général, on choisit la "valeur
de référence" de l'énergie potentielle électrique
comme une valeur où l'énergie potentielle est choisie de façon arbitraire comme étant nulle. Ceci n'est pas particulièrement choquant. En effet, c'est une pratique courante avec l'énergie potentielle (on définit le zéro
de l'énergie potentielle de gravitation à une "hauteur" zéro mais par rapport à quelle échelle de mesure?).

## Le potentiel électrique

Au chapitre précédent, nous avons défini le champs électrique
comme la force par unité de charge générée par une source.o
Ici, nous allons recommencer en définissant le **potentiel électrique**, noté $V$, comme le champs électrique par unité de charge. Ainsi si une charge, $q$, se trouve dans un champs
électrique à une position $A$, et a une énergie potentielle électrique $E_\mathrm{pot}(A)$, son **potentiel électrique**
est défini par
$$
V(A)=\frac{E_\mathrm{pot}(A)}{q}.
$$

---

Question (Unités) #

Quelles sont les unités dui potentiel électrique?

---

---

Réponse (Unités) #

Les unités du potentiel électrique sont les **volts**, $[V]$.
Ils peuvent s'exprimer en fonction des autres unités connues
comme
$$
[V]=\left[\frac{\mathrm{J}}{\mathrm{C}}\right]=\left[\frac{\mathrm{N}\cdot \mathrm{m}}{\mathrm{C}}\right]=\left[\mathrm{kg}\cdot \frac{\mathrm{m}^2}{\mathrm{s}^2\cdot \mathrm{C}}\right].
$$

---



Comme nous l'avons mentionné plus haut seule une **différence** d'énergie potentielle électrique est mesurable (il nous faut une valeur de référence).
De même seule une **différence** de potentiel électrique
peut se mesurer
$$
V(B, A)=V(B)-V(A)=\Delta_{EP}(A\rightarrow B)=\frac{E_\mathrm{pot}(B)-E_\mathrm{pot}(A)}{q}=-\frac{W_{A\rightarrow B}}{q},
$$
où $A$ et $B$ sont deux points et $W_{B\rightarrow A}$ le travail pour emmener une charge $q$ du point $B$ au point $A$.
Tout comme le champs électrique ne dépend pas de la valeur de la *charge test*, ici le potentiel ne dépend pas
de la charge test, $q$, non plus. Le potentiel électrique, $V$, ne dépend des charges qui créent le champs électrique associé. On dit que $q$ acquière l'énergie potentielle électrique en se trouvant dans le potentiel $V$ qui est créé par d'autres charges.

Pour reprendre l'exemple des plaques chargées de la @fig:epot,
on voit que la charge positive $q$ a un potentiel électrique
plus grand en $A$ qu'en $B$ et que donc elle va naturellement
se déplacer vers $B$.

---

Remarque (Référénce) #

Afin de définir le potentiel électrique en un point $A$, nous avons besoin d'une valeur de référence comme discuté plus haut. En général cette valeur est choisie arbitrairement
comme valant zéro et est le potentiel de la "terre". Tous les
autres potentiels sont donnés par rapport à cette référence.

---

---

Question (Charge négative) #

Reprenons un exemple similaire à @fig:epot, mais remplaçons la charge par une charge négative (voir @fig:epot_neg). Aussi elle se trouve au point $B$ et est libre de se déplacer.
Que va-t-il se produire? Son énergie potentielle va augmenter ou diminuer? Comment le potentiel électrique varie entre les deux points $A$ et $B$?

![Le transport d'une charge négative entre $B$ et $A$ entre deux plaques chargées infinies.](figs/epot.svg){#fig:epot_neg width=50%}

---

---

Réponse (Charge négative) #

Une charge négative va être repoussée par la plaque négative et attirée par la charge positive. Ainsi, $q$ va se déplacer vers la plaque positive, son énergie cinétique va augmenter.
A cause du principe de la conservation de l'énergie,
son énergie potentielle va donc décroître. On a que
$$
E_\mathrm{pot}(A) < E_\mathrm{pot}(B).
$$
En revanche la charge se déplace d'une d'une région avec
un potentiel élevé vers un potentiel plus faible. La variation
de potentiel électrique (qui est dûe aux plaques) est donc positive contrairement à l'énergie 
potentielle électrique
\begin{align}
&E_\mathrm{pot}(B)-E_\mathrm{pot}(A) > 0,\\
&V(B)-V(A) > 0.
\end{align}
Si la charge $q$ était positive, la variation
d'énergie potentielle aurait été négative.

---

Si on fait faire le chemin inverse à notre charge positive $q$, et qu'on la déplace de $B$ à $A$. On peut inverser la relation entre le potentiel électrique et la variation d'énergie potentielle entre les points $B$ et $A$ pour une charge $q$. On aura donc
$$
\Delta_{EP}(B\rightarrow A)=E_\mathrm{pot}(A)-E_\mathrm{pot}(B)=q\cdot V(A, B).
$$
Si la différence de potentiel est de $10\mathrm{V}$,
l'énergie potentielle d'une charge de $5\mathrm{C}$ sera augmentée de $50\mathrm{J}$.
Une charge de $10\mathrm{C}$, elle, verra son énergie potentielle électrique
augmenter de $100\mathrm{J}$ pour le même déplacement.

C'est très similaire avec ce qui se passe pour le cas de l'énergie potentielle de gravitation.
Prenons deux personnes de $m_1=50\kg$ et $m_2=100\kg$ qui monte en haut d'un immeuble de $h=20\m$.
Le potentiel dû à la gravitation est le même pour les deux en haut de l'immeuble, $g\cdot h=186\mathrm{J}$.
En revanche l'énergie potentielle de gravitation des deux objets sera différente.
Elle sera de $m_1\cdot g\cdot h\cong 980\mathrm{J}$ pour le premier objet et de
$m_2\cdot g\cdot h\cong 1860\mathrm{J}$ pour le second. Évidemment la 
comparaison n'est pas parfaite, car la charge est de deux types différents, $+$ 
et $-$, alors qu'il n'y a pas d'équivalent pour la masse.

---

Exemple (Électrons dans un tube) #

Supposons qu'un électron au repos est accéléré via une
différence de potentiel $V(B,A)=V(B)-V(A)=5000\V$ entre deux plaques
chargées. $V(B)$ correspond à la plaque chargée positivement,
et $V(A)$ à celle chargée négativement. L'électron se trouve
en $B$ au départ et a une vitesse nulle.

1. Quelle sera la variation d'énergie potentielle électrique de l'électron en 
   fonction de sa charge et du potentiel?
2. Quelle sera son énergie cinétique en fonction de la charge et du potentiel?
3. Quelle sera sa vitesse en $A$?

La masse et la charge de l'électron sont données par
$$
m_e=9\cdot 10^{-31}\ \kg,\quad q=-1.6\cdot 10^{-19}\ \C.
$$

---

---

Solution (Électrons dans un tube) #

1. La charge d'un électron est de $q=-e=-1.6\cdot 10^{-19}\C$. Son énergie 
   potentielle électrique est donc donnée par
$$
E_\mathrm{pot}=a\cdot V(B,A)=-1.6\cdot 10^{-19}\cdot 5000=-8\cdot 10^{-16} \J.
$$
L'électron perd donc de l'énergie potentielle en se rapporchant
de la plaque $A$, car il est naturellement attiré vers cette plaque. Tout comme 
une masse perd de l'énergie potentielle de gravitation quand
elle se rapproche de la terre.
2. L'énergie potentielle électrique est transformée en énergie cinétique quand 
   la charge atteint la plaque $A$. On a donc que
$$
\frac{1}{2}\cdot m\cdot v^2=-q\cdot V(A,B).
$$
On a donc que
$$
E_\mathrm{cin}=8\cdot 10^{-16}\J.
   $$
3. Finalement il nous résoudre l'équation ci-dessus pour $v$

$$
v=\sqrt{\frac{-2qV(A,B)}{m}}=4.2\cdot 10^7\frac{\m}{s}.
$$

---

---

Exercice (Et avec un proton?) #

Résoudre le même exercice que ci-dessus, mais en remplaçant
l'électron par un proton et la différence de potentielle par
$-5000\ \V$. La masse d'un proton est de $m=1.67\cdot 10^{-27}\ \kg$.

---

Afin de se donner une idée de ce que représentent les volts, vous trouverez 
dans le @tbl:volts 


          Source                   Voltage
  ------------------------ -----------------------------
         Éclair                   $10^8\ \V$
    Ligne haute tension        $10^{5-6}\ \V$
     Démarreur voiture             $10^4\ \V$
    Prise électrique                $200\ \V$
     Batterie (AA, AAA)             $1.5\ \V$
        ECG / EEG                $10^{-4}\ \V$


  : Différents potentiels et le voltage par rapport à la terre. 
  {#tbl:volts}

## Lien entre potentiel électrique et champs électrique

Au chapitre précédent, on a décrit un système chargé à
l'aide du camps électrique. Dans ce chapitre, nous avons fait une
description à l'aide du potentiel électrique. Comme la physique sous-jacente
reste identique, cela signifie qu'il doit y avoir un lien entre les deux.
Dans cette section nous allons voir comment relier l'un à l'autre
dans un cas simplifié, bien qu'on puisse généraliser
cela à n'importe quelle situation.

Considérons le cas simple de deux plaques chargées parallèles et infinies 
(comme sur la @fig:epot). La différence de potentiel entre ses plaques est de 
$V(B, A)=V(B)-V(A)$, avec la plaque $B$ qui est de charge positive et la plaque 
$A$ de charge négative. On va chercher à déterminer quel est le champs 
électrique entre
ces deux plaques à partir de la différence de potentiel $V(A,B)$.
Pour ce faire on va utiliser une charge $q>0$ et s'intéresser
au travail qu'il faut fournir pour déplacer la charge de
la plaque $A$ à la plaque $B$. La charge étant positive,
elle sera attirée par $A$ et repoussée par $B$, il faudra
donc une force externe pour lui faire effectuer ce trajet.
Comme on l'a vu au chapitre précédent, le travail est le produit
de la charge avec la différence de potentiel
$$
W = -q\cdot (V(B)-V(A))=-q\cdot V(B,A).
$${#eq:wv}
Nous savons aussi que le travail est le produit de la force
avec la distance parcourue, $d$ (ici la distance entre $A$ et $B$), ainsi
$$
W=F\cdot d.
$$
Finalement, la force et le champs électrique sont reliée par (voir le chapitre 
précédent)
$$
F=q\cdot E\Rightarrow W=q\cdot E\cdot d.
$$
En utilisant l'@eq:wv, on trouve que
\begin{align}
    -q\cdot V(B,A)&=q\cdot E\cdot d,\nonumber\\
    V(B,A)&=-E\cdot d,\nonumber\\
    E&=-\frac{V(B,A)}{d}.
\end{align}
Le signe $-$ dans cette relation indique que la *direction* du champs 
électrique est opposée
à la direction dans laquelle le potentiel diminue.
On voit aussi de cette équation que les unités du champs électrique
peuvent également s'exprimer comme des
$$
[E]=\left[\frac{\V}{\m}\right]=\left[\frac{\N}{\C}\right],
$$

---

Remarque (Plusieurs dimensions) #

Ici nous avons une grande simplification qui a été faite. En effet,
nous considérons un système unidimensionnel où le champs électrique est 
uniforme. En général le champs électrique est une quantité vectorielle et qui 
varie dans l'espace et donc le lien entre $\vec E$ et $V$ est plus compliqué. 
Néanmoins, cela est laissé pour un cours plus avancé, car les concepts 
mathématiques nécessaires dépassent les connaissances que vous avez acquises 
jusqu'ici.

---

---

Exemple (Le champs électrique et le voltage) #

Deux plaques parallèles sont chargées pour produire une différence
de potentiel de $50\ \V$. Si l'écarte entre les plaques est de $5\ \mm$, 
calculer l'amplitude du champs électrique entre les plaques.

---

---

Solution (Le champs électrique et le voltage) #

On applique simplement l'équation
\begin{equation*}
    E=\frac{V(B,A)}{d}=\frac{50}{0.005}=10000\ \frac{\V}{\m}.
\end{equation*}

---

Plus généralement, dans une région où $E$ ne serait pas
uniforme, on peut montrer que le champs électrique est proportionnel
au taux de variation spatial du potentiel électrique et a
la direction opposée
$$
E=-\frac{\Delta V}{\Delta x},
$$
où $\Delta V$ est la variation du potentiel sur une petite distance $\Delta 
x$. 

---

Exercice (Potentiel électrique dû à une charge ponctuelle) #

Soit une charge ponctuelle $Q$. A partir de la formule du champ électrique et 
de ce que nous venons de voir. Déterminer le potentiel électrostatique engendré 
par une charge ponctuelle à une distance $r$ de la charge.

---

## La capacité électrique

Un **condensateur** est un objet qui est constitué de deux conducteurs (souvent 
des plaques ou des feuilles) qui sont placées l'une proche de l'autre mais qui 
ne se touchent pas. Les condensateurs se trouvent dans un grand nombre de 
circuits électroniques. Ils servent à stocker des charges électriques qui 
peuvent être utilisées à un moment ultérieur. Ils permettent aussi d'empêcher 
les variations trop rapides de puissance électrique et ainsi protègent les 
circuits. On a pu aussi les utiliser pour la mémoire des ordinateurs dans des 
versions miniaturisées. 

Les capacités sont représentées dans des circuits électriques pas un symbole 
comme si la @fig:cap_symbol

![Un symbole représentant une capacité dans un circuit 
électrique.](figs/cap_symbol.svg){#fig:cap_symbol width=50%}

Si on applique un voltage (un potentiel), $V$, entre les deux plaques en les 
connectant à une batterie ou à une prise électrique par exemple, une des deux 
plaques va être chargée négativement tandis que l'autre sera chargée 
positivement avec des charges respectivement $-Q$ et $Q$. La charge du 
condensateur est proportionnelle à la différence de potentiel au bords du 
condensateur, ici c'est $V$, le potentiel de la batterie ou de la prise. On a 
que
$$
Q=C\cdot V,
$$
où $C$ est la capacité du condensateur et qui a des unités de Coulombs par 
Volts, appelés *farad*, $[\mathrm{F}]$. Les capacités standards se situent 
entre $1\mathrm{pF}=10^{-12}\mathrm{F}$ et 
$1\mu\mathrm{F}=10^{-6}\mathrm{F}$.

Ici, nous voyons facilement qu'on pourrait aisément confondre la capacité $C$, 
avec les unités $\C$, (les Coulombs) et le voltage $V$ avec les volts. C'est un 
peu malheureux, mais il faudra être un peu vigilant pour éviter les erreurs 
malencontreuses. 

La capacité, $C$, ne dépend en général ni du voltage, ni de la charge du 
condensateur. Elle ne dépend que de la forme et de la surface des plaques ainsi 
que de la distance entre elles et le matériau qui les sépare. Ainsi pour des 
plaques parallèles de surface $S$ et séparées par une distance $d$, on a
$$
C=\epsilon_0\frac{S}{d},
$$
où $\epsilon_0$ est la permittivité du vide qu'on a déjà vu plus tôt dans ce 
condensateurs
$$
\epsilon_0=8.85\cdot 10^{-12}\frac{\mathrm{C}^2}{\N\cdot \m^2}.
$$


---

Exemple (Application de formules) #

1. Calculer la capacité d'un condensateur donc les plaques rectangulaire ont 
   des dimensions de $10\cm\times 5\cm$ et sont séparées d'une distance de 
   $1\mm$.
2. Quelle est la charge des plaques si on connecte la capacité à une batterie 
   de $12\V$, quelle sera la charge des plaques?
3. Quelle est le champs électrique entre les plaques?
4. Quelle devrait être la distance entre les plaques pour avoir une capacité de 
   $1\F$?

---

---

Solution (Application de formules) #

1. La surface du condensateur est de $S=0.1\cdot 0.05=5\cdot10^{-3}\m^2$. On 
   peut en déduire la capacité via
\begin{equation}
    C=\epsilon_0\frac{S}{d}=8.85\cdot 10^{-12}\frac{5\cdot 
    10^{-5}}{10^{-3}}=44.3\mathrm{pF}.
\end{equation}
2. La charge des plaque est donnée par
$$
Q=C\cdot V=44.3\cdot 10^{-12}\cdot 12=5.31\cdot 10^{-10}\C.
$$
3. Le champs électrique uniforme généré par les plaques est donné par
$$
E=\frac{V}{d}=\frac{12}{10^{-3}}=1.2\cdot 10^4\frac{\V}{\m}.
$$
4. En réutilisant la même équation que pour la question (1), on peut écrire
$$
d=\epsilon_0\frac{S}{C}=8.85\cdot 10^{-12}\frac{5\cdot 10^{-3}}{1}=8.85\cdot 
10^{-15}\m.
$$
On voit donc qu'une capacité de $1\F$ est une quantité assez monstrueuse qu'il 
n'est pas possible de produire avec une aussi petite surface.
En gardant une distance de $1\mm$, on pourrait avoir une capacité de $1\F$ en 
augmentant la surface à
$$
S=\frac{Cd}{\epsilon_0}=\frac{10^{-3}}{8.85\cdot 10^{-12}}=1.13\cdot 
10^{8}\m^2,
$$
soit un carré de $10\km$ de côté...

---

Il existe une grande quantité d'applications pour les condensateurs: ils 
peuvent servir de remplacement pour les batteries, sont à la base du 
fonctionnement des microphones ou des touches de certains claviers.

---

Illustration (Touche de clavier) #

Une touche de clavier, dans certains cas, peut être attachée à une plaque de 
condensateur mobile, alors que la seconde est fixe. Entre les plaques est situé 
un isolant qui a des propriétés élastiques. Lorsque la touche est pressée, 
l'isolant se comprime et la distance entre les plaques du condensateurs change. 
Cela modifie le champs électrique entre les plaques du condensateur qui peut 
ensuite être détecté par un circuit électrique.

---

La charge d'un condensateur est reliée à la tension maximale qui peut être 
appliquée entre ses plaques, sans que la charge puisse traverser  et former un 
arc électrique (comme cela se produit lorsque la charge passe des nuages à la 
terre lors d'un orage). Ce phénomène s'appelle claquage électrique.
Cette tension dépend du matériau séparant les deux plaques.

Jusqu'ici, nous avons supposé qu'il y a de l'air (ou du vide) entre les plaques 
d'un condensateur. En général, on insère un isolant, comme du plastique, entre 
les plaques. Cet isolant est appelé un *diélectrique*. 

Le diélectrique a plusieurs propriétés intéressantes:

1. Le diélectrique est en général plus isolant que l'air, car il empêche les 
   charges de se déplacer aussi librement. Ainsi, il est possible 
   d'accumuler un plus grand voltage entre les plaques.
2. De même, les plaques du condensateurs peuvent être plus rapprochées sans que 
   les charges passent d'une plaque à l'autre. En rendant $d$ plus faible on 
   augmente la capacité.
3. On s'est rendu compte expérimentalement que la capacité d'un condensateur 
   est augmentée proportionnellement par un facteur $K$, la *constante 
   diélectrique*, ne dépendant que du diélectrique. On a donc que
$$
C=K\epsilon_0\frac{S}{d}=\epsilon\frac{S}{d},
$$
avec $\epsilon=K\epsilon_0$ la permittivité du diélectrique. Pour l'air ou le 
vide on a que $K=1$. Comme on l'a très brièvement discuté plus haut, il y a une 
valeur maximale du champs électrique qui s'applique entre les plaques d'un 
condensateur. Au delà, les charges peuvent passer entre les plaques. Cette 
valeur limite du champs est appelée *rigidité diélectrique* et peut varier 
grandement. Pour l'air elle est de $3\cdot 10^6\V/\m$, alors que pour du 
plastique elle est de l'ordre de $50\cdot 10^6\V/\m$ pour $K\cong 4$.

---

Question (Insertion de diélectrique à $V$ constant) #

Soit un condensateur composé de deux plaques séparées d'une distance $d$ et 
connecté à une batterie de voltage constant $V$ qui acquière une charge $Q$. Si 
on insère un diélectrique avec $K>1$ entre les plaques, est-ce que $Q$ va 
augmenter, diminuer, ou rester le même?

---

---

Réponse (Insertion de diélectrique à $V$ constant) #

Le voltage $V$ reste constant, alors que $C$ augmente à cause de la relation 
$C=K\epsilon_0 S/d$. On déduit donc de la relation $Q=CV$ que $Q$ doit 
augmenter pour $K>1$. Ainsi, quand on insère un diélectrique dans un 
condensateur plus de charges seront retirées de la batterie pour être amenées 
sur les plaques du condensateur.

---

---

Question (Insertion de diélectrique dans un condensateur isolé) #

Soit un condensateur composé de deux plaques séparée par de l'air, chargé à une 
charge $Q$ et déconnecté de la batterie. On insère ensuite un diélectrique avec 
$K>1$. Est-ce que $Q$, $V$, ou $C$ vont changer?

---

---

Réponse(Insertion de diélectrique dans un condensateur isolé) #

La charge $Q$ reste la même comme le condensateur est isolé du reste du monde. 
La capacité elle augmente à cause de la permittivité augmentée. Ainsi la 
tension entre les plaque diminue à cause de $V=Q/C$.

---

### Description moléculaire des diélectriques

D'un point de vue phénoménologique, il est intéressant de comprendre pourquoi 
la présence d'un diélectrique augment la capacité d'un condensateur. Un 
condensateur dont les plaques sont séparées par de l'air aura une capacité 
$C_0$ et s'il est soumis à une tension $V_0$ aura une charge $Q$. Si nous 
insérons un diélectrique entre les plaques, à cause du champs électrique entre 
les plaques, les charges à l'intérieur du diélectrique vont se déplacer 
légèrement (les électrons vont s'approcher de la charge positive et laissant 
les protons plus proches de la charge négative). Cela va créer une petite 
charge nette négative du côté de la plaque positive et une petite charge 
positive du côté de la plaque négative. Cela aura pour effet "d'annuler" 
certaines lignes de champs à l'intérieur du diélectrique (mais pas toutes) et 
ainsi le voltage est également réduit (pour une charge constante).

<!-- TODO Maybe add storage of energy (maybe it's too muche) -->


## Résumé

Dans ce chapitre nous avons vu les concepts suivants:

* Le potentiel électrique est l'énergie potentielle électrique par unité de 
  charge.
* La différence de potentiel électrique entre deux points est défini par le 
  travail nécessaire pour déplacer une charge de $1\C$ entre ces deux points 
  et est mesurée en volts, $\V=\J/\V$.
* La différence de potentiel entre deux points, $A,B$, dans un champs 
  électrique uniforme $E$ est donnée par

  $$V=-E\cdot d,$$
  avec $d$ la distance entre $A$ et $B$.
* Une charge $Q$ engendre un potentiel électrique
$$
V=k\frac{Q}{r}.
$$
* Un condensateur est un système composé de deux conducteurs séparé par un 
  isolant.
* La capacité, $C$, d'un condensateur se définit en fonction de sa charge et du 
  potentiel entre les deux conducteurs
  $$
  C=Q/V.
  $$
* Elle peut également se définir par des considérations géométriques et des 
  propriétés intrinsèques de l'isolant
  $$
  C=\epsilon\frac{S}{d},
  $$
  avec $\epsilon=K\epsilon_0$ la permittivité de l'isolant, $d$ la distance 
  entre les conducteurs, et $S$ leurs surface.
